/**************************************************************************/
/*  Klavaro - a flexible touch typing tutor                               */
/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
/*                                                                        */
/*  This program is free software, licensed under the terms of the GNU    */
/*  General Public License as published by the Free Software Foundation,  */
/*  which is also included in this package, in a file named "COPYING".    */
/**************************************************************************/

/*
 * Time for cursor blinkings, in miliseconds
 */
#define TIME_CURSOR_ON 800
#define TIME_CURSOR_OFF 400

/*
 * Interface functions
 */
gboolean cursor_get_blink (void);

void cursor_set_blink (gboolean status);

/*
 * Auxilaiar functions
 */
void cursor_paint_char (gchar * color_tag_name);

gint cursor_advance (gint n);

gunichar cursor_get_char (void);

gboolean cursor_init (gpointer data);

gboolean cursor_on (gpointer data);

gboolean cursor_off (gpointer data);

void cursor_switch_on (void);

void cursor_switch_off (void);
